aboutsummaryrefslogtreecommitdiffstats
path: root/dist/svg.js
diff options
context:
space:
mode:
Diffstat (limited to 'dist/svg.js')
-rw-r--r--dist/svg.js13
1 files changed, 8 insertions, 5 deletions
diff --git a/dist/svg.js b/dist/svg.js
index c647995..ec328f5 100644
--- a/dist/svg.js
+++ b/dist/svg.js
@@ -1,4 +1,4 @@
-/* svg.js v0.15 - svg regex default color viewbox bbox rbox element container fx event group arrange defs mask clip pattern gradient doc shape rect ellipse line poly path plotable image text nested sugar - svgjs.com/license */
+/* svg.js v0.15-2-g80f89b2 - svg regex default color viewbox bbox rbox element container fx event group arrange defs mask clip pattern gradient doc shape rect ellipse line poly path plotable image text nested sugar - svgjs.com/license */
;(function() {
this.SVG = function(element) {
@@ -904,10 +904,13 @@
/* remove children */
for (var i = this.children().length - 1; i >= 0; i--)
this.removeElement(this.children()[i])
-
- /* create new defs node */
- this.defs()
-
+
+ /* remove defs node */
+ if (this._defs) {
+ this._defs.remove()
+ delete this._defs
+ }
+
return this
}